@@ -23,6 +23,12 @@ pub struct GameLoop {
 
 impl GameLoop {
     /// Create the GameLoop with the tick rate (interval)
+    /// ```rust, no_run
+    /// use rollo::game::GameLoop;
+    /// use std::time::Duration;
+    ///
+    /// let game_loop = GameLoop::new(Duration::from_millis(25));
+    /// ```
     pub fn new(interval: Duration) -> Self {
         Self {
             date: AtomicI64::new(Self::current_timestamp().unwrap()),
@@ -107,7 +113,7 @@ mod tests {
     use async_trait::async_trait;
     use tokio::time::sleep;
 
-    #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
+    #[tokio::test]
     async fn test_get_sleep_time() {
         let mut game_loop = GameLoop::new(Duration::from_millis(75));
         sleep(Duration::from_millis(500)).await;
@@ -125,7 +131,7 @@ mod tests {
         assert_eq!(game_loop.get_sleep_time(), 0);
     }
 
-    #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
+    #[tokio::test]
     async fn test_sleep_loop() {
         let mut game_loop = GameLoop::new(Duration::from_millis(25));
         let timer = Instant::now();
@@ -146,7 +152,7 @@ mod tests {
         assert!((68..=85).contains(&sleep_time));
     }
 
-    #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
+    #[tokio::test]
     async fn test_update_time() {
         let mut game_loop = GameLoop::new(Duration::from_millis(25));
         sleep(Duration::from_millis(10)).await;
@@ -156,7 +162,7 @@ mod tests {
     }
 
     #[should_panic(expected = "Test : update")]
-    #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
+    #[tokio::test]
     async fn test_loop() {
         let mut game_loop = GameLoop::new(Duration::from_millis(25));
         let world = Box::new(TestGameLoop {
