@@ -163,23 +163,36 @@ where
         let size = reader.read_size().await?;
         let cmd = reader.read_cmd().await?;
 
-        let (limit, size_limit, policy) = self.world.get_packet_limit(cmd);
+        let (gloabl_amount_limit, global_size_limit) = self.world.global_limit();
+        let (packet_amount_limit, packet_size_limit, policy) = self.world.get_packet_limit(cmd);
 
-        if (size as u32) >= size_limit || size >= MAX_SIZE {
+        if size >= MAX_SIZE || (size as u32) >= packet_size_limit {
             return Err(Error::PacketSize);
         }
 
-        if !self
-            .dos_protection
-            .evaluate_cmd(cmd, limit, self.world.time())
+        let time = self.world.time();
+
+        let global_result = self.dos_protection.evaluate_global_limit(
+            time,
+            size as u32,
+            global_size_limit,
+            gloabl_amount_limit,
+        );
+
+        if !global_result
+            || !self
+                .dos_protection
+                .evaluate_cmd(cmd, packet_amount_limit, time)
         {
             WorldSession::on_dos_attack(&self.world_session, self.world, cmd).await;
+
+            if !global_result {
+                return Err(self.close_dos());
+            }
+
             match policy {
                 DosPolicy::Close => {
-                    if self.world_session.socket_tools().close().is_err() {
-                        log::error!("Error when closing the channel.");
-                    }
-                    return Err(Error::DosProtection);
+                    return Err(self.close_dos());
                 }
                 DosPolicy::Log => {
                     log::info!("Potential dos attack detected for Cmd {}.", cmd);
@@ -197,6 +210,13 @@ where
         }
     }
 
+    fn close_dos(&self) -> Error {
+        if self.world_session.socket_tools().close().is_err() {
+            log::error!("Error when closing the channel.");
+        }
+        Error::DosProtection
+    }
+
     async fn write(mut writer: WriteHalf<S>, mut rx: UnboundedReceiver<WriterMessage>) {
         #[cfg(feature = "flatbuffers_helpers")]
         let mut builder = flatbuffers::FlatBufferBuilder::new();
